@@ -149,7 +149,7 @@ class DockNotebook(gtk.Notebook):
         self.set_tab_pos(gtk.POS_BOTTOM)
         self.set_scrollable(True)
         self.set_homogeneous_tabs(False)
-        self.popup_enable()
+        self.popup_disable()
         self.connect("page-removed", self.on_page_count_changed)
         self.connect("page-added", self.on_page_count_changed)
         
